﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Reflection;

namespace RealTimeDataChartSilverlight
{
    public partial class MainPage : UserControl
    {
        //indicates whether the data feed is running
        private bool isTimerRunning = false;
        //buffers to store the data for the two charts
        TickerBuffer tickerBuffer = new TickerBuffer(DataLoader.HistoricalData);
        TickerBuffer offsetTickerBuffer = new TickerBuffer(DataLoader.HistoricalData);
        //timer to control adding data to the buffer
        System.Windows.Threading.DispatcherTimer realTimeDataFeedTimer;
        public MainPage()
        {
            InitializeComponent();
        }

        void realTimeDataFeedTimer_Tick(object sender, EventArgs e)
        {
            //adding one record from the historical data to the data bound to the WPF chart component
            tickerBuffer.AddRecordsFromHistoricalData(1);
            offsetTickerBuffer.AddRecordsFromHistoricalData(1);
        }

        private void windowSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            //change the window size in response to the window size slider value change
            if (windowSlider != null)
            {
                tickerBuffer.WindowSize = (int)windowSlider.Value;
                offsetTickerBuffer.WindowSize = (int)windowSlider.Value;
                windowSizeLb.Content = ((int)windowSlider.Value).ToString();
            }
        }

        private void periodSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            //change the timer interval in response to the interval slider value change
            if (intervalSlider != null)
            {
                realTimeDataFeedTimer.Interval = TimeSpan.FromMilliseconds(intervalSlider.Value);
                intervalLb.Content = ((int)intervalSlider.Value).ToString() + "ms";
            }
        }

        private void button1_Click(object sender, RoutedEventArgs e)
        {
            //start or stop the timer depending on whether it's already running
            if (isTimerRunning)
            {
                realTimeDataFeedTimer.Stop();
                button1.Content = "Start Feed";
                isTimerRunning = false;
            }
            else
            {
                realTimeDataFeedTimer.Start();
                button1.Content = "Stop Feed";
                isTimerRunning = true;
            }
        }

        private void fillWindowBtn_Click(object sender, RoutedEventArgs e)
        {
            //fill the buffer up to its current window size with data
            tickerBuffer.AddRecordsFromHistoricalData(tickerBuffer.WindowSize);
            offsetTickerBuffer.AddRecordsFromHistoricalData(offsetTickerBuffer.WindowSize);
        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            //setting up timer
            realTimeDataFeedTimer = new System.Windows.Threading.DispatcherTimer();
            realTimeDataFeedTimer.Interval = new TimeSpan();
            realTimeDataFeedTimer.Tick += new EventHandler(realTimeDataFeedTimer_Tick);

            //fill the ticker buffer with historical data
            tickerBuffer.AddRecordsFromHistoricalData(tickerBuffer.WindowSize);
            //load the second buffer with different data from the same dataset (starting at position 2000)
            offsetTickerBuffer.AddRecordsFromHistoricalData(tickerBuffer.WindowSize, 2000);

            //associating the data sets with the charts
            xamDataChart1.DataContext = this.tickerBuffer;
            xamDataChart2.DataContext = this.offsetTickerBuffer;

            realTimeDataFeedTimer.Interval = TimeSpan.FromMilliseconds(intervalSlider.Value);
            intervalLb.Content = ((int)intervalSlider.Value).ToString() + "ms";
            windowSizeLb.Content = ((int)windowSlider.Value).ToString();
        }
    }
}
